import OpenSeries.fisika as fisika

# menghitung masa jenis benda
massa_benda = 14
volume_benda = 8
print(
    f"menghitung massa jenis benda dengan massa benda {massa_benda} gram, dan volume benda {volume_benda} cm3"
)
print(f"hasilnya adalah : {fisika.masa_jenis(massa_benda, volume_benda)}\n")
