import OpenSeries.fisika as fisika

# menghitung hukum arus ohm
kuat_arus = 30
hambatan = 3
print("menghitung hukum ohm")
print(f"dengan kuat arus {kuat_arus}")
print(f"hambatan {hambatan}")
print(f"hasilnya adalah: {fisika.hukum_ohm(kuat_arus, hambatan)}\n")
