import OpenSeries.matematika as matematika

nilai1 = 24
nilai2 = 40
print(
    f"hitung nilai fpb (faktor persekutuan terbesar) dari nilai {nilai1} dan {nilai2}"
)
print(f"hasilnya adalah : {matematika.fpb(nilai1, nilai2)}\n")
