# bilangan pi adalah nilai konstant dalam matematika yang merupakan perbandingan keliling
# lingkaran dengan diameternya
pi: float = 3.14159265358979323846

# bilangan euler adalah nilai konstant yang dimana nilai kira-kiranya sama dengan 2.71828
# dan dikarakterisasi dalam berbagai cara
bilangan_euler: float = 2.718281828459045235360
