import OpenSeries.fisika as fisika

# fungsi menghitung glbb
print("hitung glbb (gerak lurus beraturan)")
result_glbb = fisika.gerak_lurus_beraturan(10, 2, 3)
print(f"hasil dari glbb adalah: {result_glbb}\n")
